==> ruby-ffi-libarchive_1.0.0+.orig.tar.gz: ffi-libarchive-1.0.0/CHANGELOG.md <==
<!-- usage documentation: http://expeditor-docs.es.chef.io/configuration/changelog/ -->
# Change Log

<!-- latest_release 1.0.0 -->
## [v1.0.0](https://github.com/chef/ffi-libarchive/tree/v1.0.0) (2019-12-28)

#### Merged Pull Requests
-  Add Ruby 2.7rc testing and cache gem installs in Buildkite [#28](https://github.com/chef/ffi-libarchive/pull/28) ([tas50](https://github.com/tas50))
<!-- latest_release -->

<!-- release_rollup since=0.4.10 -->
### Changes not yet released to rubygems.org

#### Merged Pull Requests
-  Add Ruby 2.7rc testing and cache gem installs in Buildkite [#28](https://github.com/chef/ffi-libarchive/pull/28) ([tas50](https://github.com/tas50)) <!-- 1.0.0 -->
- Add support for custom read functions [#27](https://github.com/chef/ffi-libarchive/pull/27) ([jatoben](https://github.com/jatoben)) <!-- 0.4.12 -->
- Chefstyle fixes to get the build green again [#25](https://github.com/chef/ffi-libarchive/pull/25) ([tas50](https://github.com/tas50)) <!-- 0.4.11 -->
<!-- release_rollup -->

<!-- latest_stable_release -->
## [v0.4.10](https://github.com/chef/ffi-libarchive/tree/v0.4.10) (2019-06-24)

#### Merged Pull Requests
- Add a code of conduct file [#17](https://github.com/chef/ffi-libarchive/pull/17) ([tas50](https://github.com/tas50))
- Update the project to be part of Chef Foundation [#19](https://github.com/chef/ffi-libarchive/pull/19) ([tas50](https://github.com/tas50))
- Replace Travis CI with Buildkite for testing [#20](https://github.com/chef/ffi-libarchive/pull/20) ([tas50](https://github.com/tas50))
- Silence warnings with constants [#21](https://github.com/chef/ffi-libarchive/pull/21) ([tas50](https://github.com/tas50))
<!-- latest_stable_release -->

## [v0.4.6](https://github.com/chef/ffi-libarchive/tree/v0.4.6) (2018-12-07)

#### Merged Pull Requests
- Don&#39;t ship test and development files in the gem artifact [#15](https://github.com/chef/ffi-libarchive/pull/15) ([tas50](https://github.com/tas50))
- Add gem and travis badges [#16](https://github.com/chef/ffi-libarchive/pull/16) ([tas50](https://github.com/tas50))

## [v0.4.4](https://github.com/chef/ffi-libarchive/tree/v0.4.4) (2018-11-01)

#### Merged Pull Requests
- Update expeditor / travis and add github templates [#14](https://github.com/chef/ffi-libarchive/pull/14) ([tas50](https://github.com/tas50))
- Add search pattern for Windows&#39; libarchive-13.dll [#13](https://github.com/chef/ffi-libarchive/pull/13) ([bdwyertech](https://github.com/bdwyertech))

## [v0.4.2](https://github.com/chef/ffi-libarchive/tree/v0.4.2) (2018-07-21)

#### Merged Pull Requests
- Use OR instead of AND for file extraction flags [#11](https://github.com/chef/ffi-libarchive/pull/11) ([RoboticCheese](https://github.com/RoboticCheese))

## [v0.4.1](https://github.com/chef/ffi-libarchive/tree/v0.4.1) (2018-06-13)

#### Merged Pull Requests
- Add some basic usage docs [#10](https://github.com/chef/ffi-libarchive/pull/10) ([thommay](https://github.com/thommay))

==> ruby-ffi-libarchive_1.0.1.orig.tar.gz: ffi-libarchive-1.0.1/CHANGELOG.md <==
<!-- usage documentation: http://expeditor-docs.es.chef.io/configuration/changelog/ -->
# Change Log

<!-- latest_release 1.0.1 -->
## [v1.0.1](https://github.com/chef/ffi-libarchive/tree/v1.0.1) (2020-04-19)

#### Merged Pull Requests
- Optionally clone entries when iterating through an archive [#30](https://github.com/chef/ffi-libarchive/pull/30) ([jatoben](https://github.com/jatoben))
<!-- latest_release -->

<!-- release_rollup since=1.0.0 -->
### Changes not yet released to rubygems.org

#### Merged Pull Requests
- Optionally clone entries when iterating through an archive [#30](https://github.com/chef/ffi-libarchive/pull/30) ([jatoben](https://github.com/jatoben)) <!-- 1.0.1 -->
<!-- release_rollup -->

<!-- latest_stable_release -->
## [v1.0.0](https://github.com/chef/ffi-libarchive/tree/v1.0.0) (2019-12-28)

#### Merged Pull Requests
- Chefstyle fixes to get the build green again [#25](https://github.com/chef/ffi-libarchive/pull/25) ([tas50](https://github.com/tas50))
- Add support for custom read functions [#27](https://github.com/chef/ffi-libarchive/pull/27) ([jatoben](https://github.com/jatoben))
-  Add Ruby 2.7rc testing and cache gem installs in Buildkite [#28](https://github.com/chef/ffi-libarchive/pull/28) ([tas50](https://github.com/tas50))
<!-- latest_stable_release -->

## [v0.4.10](https://github.com/chef/ffi-libarchive/tree/v0.4.10) (2019-06-24)

#### Merged Pull Requests
- Add a code of conduct file [#17](https://github.com/chef/ffi-libarchive/pull/17) ([tas50](https://github.com/tas50))
- Update the project to be part of Chef Foundation [#19](https://github.com/chef/ffi-libarchive/pull/19) ([tas50](https://github.com/tas50))
- Replace Travis CI with Buildkite for testing [#20](https://github.com/chef/ffi-libarchive/pull/20) ([tas50](https://github.com/tas50))
- Silence warnings with constants [#21](https://github.com/chef/ffi-libarchive/pull/21) ([tas50](https://github.com/tas50))

## [v0.4.6](https://github.com/chef/ffi-libarchive/tree/v0.4.6) (2018-12-07)

#### Merged Pull Requests
- Don&#39;t ship test and development files in the gem artifact [#15](https://github.com/chef/ffi-libarchive/pull/15) ([tas50](https://github.com/tas50))
- Add gem and travis badges [#16](https://github.com/chef/ffi-libarchive/pull/16) ([tas50](https://github.com/tas50))

## [v0.4.4](https://github.com/chef/ffi-libarchive/tree/v0.4.4) (2018-11-01)

#### Merged Pull Requests
- Update expeditor / travis and add github templates [#14](https://github.com/chef/ffi-libarchive/pull/14) ([tas50](https://github.com/tas50))
- Add search pattern for Windows&#39; libarchive-13.dll [#13](https://github.com/chef/ffi-libarchive/pull/13) ([bdwyertech](https://github.com/bdwyertech))

## [v0.4.2](https://github.com/chef/ffi-libarchive/tree/v0.4.2) (2018-07-21)

#### Merged Pull Requests
- Use OR instead of AND for file extraction flags [#11](https://github.com/chef/ffi-libarchive/pull/11) ([RoboticCheese](https://github.com/RoboticCheese))

## [v0.4.1](https://github.com/chef/ffi-libarchive/tree/v0.4.1) (2018-06-13)

#### Merged Pull Requests
- Add some basic usage docs [#10](https://github.com/chef/ffi-libarchive/pull/10) ([thommay](https://github.com/thommay))
